'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _index = require('../index');

exports.default = function (Vue, $root) {

    Vue.component('edu-modal', _index.EduModal);
    Vue.component('edu-dialog', _index.EduDialog);

    var vm = new Vue({
        data: {
            dialogVisible: true,
            title: '提示',
            content: '',
            cancel: function cancel() {},
            cancelText: "取消",
            confirm: function confirm() {},
            confirmText: "确定",
            size: "normal",
            close: function close() {}
        },
        template: '<edu-dialog v-model=\'dialogVisible\' \n                    :title=\'title\' \n                    :content=\'content\' \n                    :cancel=\'cancel\'\n                    :cancelText=\'cancelText\'\n                    :confirm=\'confirm\'\n                    :confirmText=\'confirmText\' \n                    :size=\'size\'\n                    :close=\'close\'\n                    >\n                </edu-dialog>'
    });

    var isString = function isString(str) {
        return typeof str === 'string' ? true : false;
    };

    Vue.prototype.$dialog = {
        init: function init(options) {
            if (!vm.$el) {
                vm.$mount("#globalDialog");
            }

            vm.dialogVisible = true;
            if (options.title) {
                vm.title = options.title;
            } else {
                vm.title = "提示";
            }
            if (options.content) {
                vm.content = options.content;
            }
            if (options.cancel != null) {
                vm.cancel = options.cancel;
            }
            if (options.cancelText) {
                vm.cancelText = options.cancelText;
            }

            vm.confirm = options.confirm || function () {};

            if (options.confirmText) {
                vm.confirmText = options.confirmText;
            }
            if (options.size) {
                vm.size = options.size;
            }
            if (options.close) {
                vm.close = options.close;
            } else {
                vm.close = function () {};
            }
        },
        alert: function alert(arg1, arg2) {
            var options = {};
            if (isString(arg1)) {
                options = {
                    title: "提示",
                    content: arg1,
                    confirm: arg2
                };
            } else {
                options = arg1;
            }
            if (!options.cancel) {
                options.cancel = false;
            }

            this.init(options);
        },
        success: function success(arg1, arg2) {
            var options = {};
            if (isString(arg1)) {
                options = {
                    title: "提示",
                    content: arg1,
                    confirm: arg2
                };
            } else {
                options = arg1;
            }
            if (!options.cancel) {
                options.cancel = false;
            }

            this.init(options);
        },
        error: function error(arg1, arg2) {
            var options = {};
            if (isString(arg1)) {
                options = {
                    title: "错误提示",
                    content: arg1,
                    confirm: arg2
                };
            } else {
                options = arg1;
            }
            if (!options.cancel) {
                options.cancel = false;
            }
            this.init(options);
        },
        confirm: function confirm(arg1, arg2, arg3) {
            var options = {};
            if (isString(arg1)) {
                options = {
                    title: "确认信息",
                    content: arg1,
                    confirm: arg2,
                    cancel: function () {} || arg3
                };
            } else {
                options = arg1;
            }
            this.init(options);
        },
        open: function open(options) {
            this.init(options);
        }
    };
};